@@ -1,13 +1,13 @@
 # Copyrights 2007-2008 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.04.
+# Pod stripped from pm file by OODoc 1.05.
 use warnings;
 use strict;
 
 package Log::Report::Dispatcher;
 use vars '$VERSION';
-$VERSION = '0.18';
+$VERSION = '0.19';
 
 
 use Log::Report 'log-report', syntax => 'SHORT';
@@ -16,6 +16,7 @@ use Log::Report::Util qw/parse_locale expand_reasons %reason_code
 
 use POSIX      qw/strerror/;
 use List::Util qw/sum/;
+use Encode     qw/find_encoding FB_DEFAULT/;
 
 eval { POSIX->import('locale_h') };
 if($@)
@@ -68,6 +69,12 @@ sub init($)
         or error __x"illegal format_reason '{format}' for dispatcher",
              format => $f;
 
+    my $cs  = delete $args->{charset} || ($^O eq 'MSWin32'?'UTF-16':'UTF-8');
+    my $enc = find_encoding $cs
+        or error __x"Perl does not support charset {cs}", cs => $cs;
+    $self->{charset_enc}
+      = sub { no warnings 'utf8'; $enc->decode($_[0], FB_DEFAULT) };
+
     $self;
 }
 
@@ -195,7 +202,7 @@ sub translate($$$)
     setlocale(&LC_ALL, $oldloc)
         if defined $oldloc;
 
-    $text;
+    $self->{charset_enc}->($text);
 }
 
 
